/* WARNING: This is a generated file!  Edits will be lost! */
/*
 * Copyright (c) 2015      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * Copyright (c) 2015      Cisco Systems, Inc.  All rights reserved.
 * $COPYRIGHT$
 *
 * This file was generated by gen-mpi-mangling.pl
 */

/* Note that the rationale for the types of each of these variables is
   discussed in ompi/include/mpif-common.h.  Do not change the types
   without also changing ompi/runtime/ompi_mpi_init.c and
   ompi/include/mpif-common.h. */

extern char mpi_fortran_argv_null_;
#define OMPI_IS_FORTRAN_ARGV_NULL(addr) \
        (addr == (void*) &mpi_fortran_argv_null_)

extern char mpi_fortran_argvs_null_;
#define OMPI_IS_FORTRAN_ARGVS_NULL(addr) \
        (addr == (void*) &mpi_fortran_argvs_null_)

extern int mpi_fortran_bottom_;
#define OMPI_IS_FORTRAN_BOTTOM(addr) \
        (addr == (void*) &mpi_fortran_bottom_)

extern int mpi_fortran_errcodes_ignore_;
#define OMPI_IS_FORTRAN_ERRCODES_IGNORE(addr) \
        (addr == (void*) &mpi_fortran_errcodes_ignore_)

extern int mpi_fortran_in_place_;
#define OMPI_IS_FORTRAN_IN_PLACE(addr) \
        (addr == (void*) &mpi_fortran_in_place_)

extern int * mpi_fortran_status_ignore_;
#define OMPI_IS_FORTRAN_STATUS_IGNORE(addr) \
        (addr == (void*) &mpi_fortran_status_ignore_)

extern int * mpi_fortran_statuses_ignore_;
#define OMPI_IS_FORTRAN_STATUSES_IGNORE(addr) \
        (addr == (void*) &mpi_fortran_statuses_ignore_)

extern int mpi_fortran_unweighted_;
#define OMPI_IS_FORTRAN_UNWEIGHTED(addr) \
        (addr == (void*) &mpi_fortran_unweighted_)

extern int mpi_fortran_weights_empty_;
#define OMPI_IS_FORTRAN_WEIGHTS_EMPTY(addr) \
        (addr == (void*) &mpi_fortran_weights_empty_)

